geolocate.classes.parser module — Geolocate 1.3.0 documentation

# geolocate.classes.parser module

geolocate parser

Programmed by: Dante Signal31

email: dante.signal31@gmail.com

class `geolocate.classes.parser.` `GeolocateInputParser`(verbosity, geoip_database, text=None)

  Bases: `object`

  `VERBOSITY_LEVELS` = range(0, 4)
  `__init__`(verbosity, geoip_database, text=None)

class `geolocate.classes.parser.` `InputReader`

  Bases: `object`

  Iterator to read piped input from other programs.

  `__init__`()